**Start with our documentation: https://humboldt-penguin.github.io/redplanet/**

RedPlanet is an open-source Python library for working with various Mars geophysical datasets. We aim to streamline data analysis/visualization workflows for beginners and experts alike, so you spend less time hunting/wrangling data and more time doing cool science! :)

Huge thanks to my incredible advisor [Prof. Lujendra Ojha](https://www.lujendraojha.com/) for all his support, guidance, patience, and kindness over the past four years.

&nbsp;

---

NOTE: I completely rewrote this project in 2024 September, erasing the entire git history and restarting from scratch. On PyPI, I deleted the only version which which was ever published (v1.0.0), so it's impossible to download now (as opposed to "yanking" which would allow for downloading if the exact version were accidentally requested). An archive of the old repo is available here: https://github.com/Humboldt-Penguin/redplanet_archive-240910
